==> pedbarrayv10.db_2.0.2.tar.gz: pedbarrayv10.db/man/pedbarrayv10_dbconn.Rd <==
\name{pedbarrayv10_dbconn}

\alias{pedbarrayv10_dbconn}
\alias{pedbarrayv10_dbfile}
\alias{pedbarrayv10_dbschema}
\alias{pedbarrayv10_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  pedbarrayv10_dbconn()
  pedbarrayv10_dbfile()
  pedbarrayv10_dbschema(file="", show.indices=FALSE)
  pedbarrayv10_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{pedbarrayv10_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{pedbarrayv10_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{pedbarrayv10_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{pedbarrayv10_dbschema} prints the schema definition of the
  package annotation DB.

  \code{pedbarrayv10_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{pedbarrayv10_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{pedbarrayv10_dbfile}: a character string with the path to the
  package annotation DB.

  \code{pedbarrayv10_dbschema}: none (invisible \code{NULL}).

  \code{pedbarrayv10_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(pedbarrayv10_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by pedbarrayv10_dbconn() was created with:
  dbConnect(SQLite(), dbname=pedbarrayv10_dbfile(), cache_size=64000, synchronous=0)

  pedbarrayv10_dbschema()

  pedbarrayv10_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> pedbarrayv10.db_2.9.0.tar.gz: pedbarrayv10.db/man/pedbarrayv10_dbconn.Rd <==

\name{pedbarrayv10_dbconn}

\alias{pedbarrayv10_dbconn}
\alias{pedbarrayv10_dbfile}
\alias{pedbarrayv10_dbschema}
\alias{pedbarrayv10_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  pedbarrayv10_dbconn()
  pedbarrayv10_dbfile()
  pedbarrayv10_dbschema(file="", show.indices=FALSE)
  pedbarrayv10_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{pedbarrayv10_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{pedbarrayv10_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{pedbarrayv10_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{pedbarrayv10_dbschema} prints the schema definition of the
  package annotation DB.

  \code{pedbarrayv10_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{pedbarrayv10_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{pedbarrayv10_dbfile}: a character string with the path to the
  package annotation DB.

  \code{pedbarrayv10_dbschema}: none (invisible \code{NULL}).

  \code{pedbarrayv10_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(pedbarrayv10_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by pedbarrayv10_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=pedbarrayv10_dbfile(), cache_size=64000,
  synchronous=0)

  pedbarrayv10_dbschema()

  pedbarrayv10_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
